@@ -37,7 +37,7 @@ class MostSimilarRequest(BaseModel):
     top_n: int = 10
 
     @root_validator
-    def check_word_xor_vector(cls, values):
+    def check_word_xor_vector(cls, values):  # pylint: disable=no-self-argument
         word = values.get("word")
         vector = values.get("vector")
         if word and vector:
