@@ -3,7 +3,7 @@ from typing import List
 from codenames.game import Guess, Hint
 from pydantic import BaseModel
 
-from . import ModelIdentifier, Solver
+from .base import ModelIdentifier, Solver
 
 
 class BaseResponse(BaseModel):
